@@ -19,7 +19,7 @@ AtteanX::Store::LDF - Linked Data Fragment RDF store
     use AtteanX::Store::LDF;
 
     my $uri   = 'http://fragments.dbpedia.org/2014/en';
-    my $store = Attean->get_store('LDF')->new(start_url => $uri);
+    my $store = Attean->get_store('LDF')->new(endpoint_url => $uri);
 
     my $iter = $store->get_triples(undef,undef,literal("Albert Einstein"));
 
@@ -38,24 +38,21 @@ AtteanX::Store::LDF provides a triple-store connected to a Linked Data Fragment
 For more information on Triple Pattern Fragments consult L<http://linkeddatafragments.org/>
 
 =cut
-
 use v5.14;
 use warnings;
 
 package AtteanX::Store::LDF;
 
-our $VERSION = '0.005_03';
+our $VERSION = '0.001';
 
 use Moo;
 use Attean::API::Store;
 use Type::Tiny::Role;
-use Types::URI -all;
+use Types::Standard qw(Str);
 use RDF::LDF;
 use namespace::clean;
-use Carp;
-
-with 'Attean::API::TripleStore', 'MooX::Log::Any';
 
+with 'Attean::API::TripleStore';
 
 =head1 METHODS
 
@@ -64,25 +61,18 @@ L<Attean::API::TripleStore> class.
 
 =over 4
 
-=item new( start_url => $start_url )
+=item new( endpoint_url => $endpoint_url )
 
-Returns a new LDF-backed storage object. The required C<start_url>
-argument is a URL pointing at any Linked Data Fragment. The attribure
-will be coerced, so it can be a string, a URI object, etc.
+Returns a new LDF-backed storage object.
 
 =cut
 
-has start_url => (is => 'ro', isa => Uri, coerce => 1, required => 1);
-has endpoint_url => (is => 'ro', lazy => 1, builder => '_croak_on_endpoint');
+has endpoint_url => (is => 'ro', isa => Str, required => 1);
 has ldf => (is => 'ro', lazy => 1, builder => '_ldf');
 
-sub _croak_on_endpoint {
-	Carp::croak "endpoint_url has been deprecated, use start_url instead";
-}
-
 sub _ldf {
     my $self = shift;
-    RDF::LDF->new(url => $self->start_url->as_string);
+    RDF::LDF->new(url => $self->endpoint_url);
 }
 
 sub _term_as_string {
@@ -90,10 +80,7 @@ sub _term_as_string {
     if (!defined $term) {
         return undef
     }
-	 elsif ($term->is_variable) {
-		 return undef;
-	 }
-    elsif ($term->is_literal) {
+    elsif ($term->does('Attean::API::Literal')) {
         return $term->as_string; # includes quotes and any language or datatype
     } 
     else {
@@ -101,13 +88,13 @@ sub _term_as_string {
     }
 }
 
-=item count_triples_estimate( $subject, $predicate, $object ) 
+=item count_triples ( $subject, $predicate, $object ) 
 
 Return the count of triples matching the specified subject, predicate and 
 objects.
 
 =cut
-sub count_triples_estimate {
+sub count_triples {
     my $self    = shift;
     my ($s_pattern,$p_pattern,$o_pattern) = @_;
            
@@ -121,7 +108,7 @@ sub count_triples_estimate {
 
     my ($statement,$info) = $ldf_iter->();
 
-    return $info->{'void_triples'};
+    return $info->{'hydra_totalItems'};
 }
 
 =item get_triples( $subject, $predicate, $object)
@@ -184,28 +171,6 @@ sub get_triples {
     return $iter;
 }
 
-=item cost_for_plan($plan)
-
-Returns an cost estimation for a single LDF triple based on
-estimates. The cost will be in the interval 10-1000 if the supplied
-argument is a L<AtteanX::Store::LDF::Plan::Triple>, undef otherwise.
-
-=cut
-
-sub cost_for_plan {
-	my $self	= shift;
- 	my $plan	= shift;
-	if ($plan->isa('AtteanX::Store::LDF::Plan::Triple')) {
-		my $totals = $self->count_triples_estimate();
-		if ($totals < 1) {
-			$self->log->error("Total number of triples in model were $totals, probably an error");
-			return 10000; # Probably a plan we don't want
-		}
-		return 10 + int(990 * $self->count_triples_estimate($plan->values) / $totals)
-	}
-	return;
-}
-
 1;
 
 __END__
@@ -224,12 +189,10 @@ at L<https://github.com/phochste/AtteanX-Store-LDF>.
 =head1 AUTHOR
 
 Patrick Hochstenbach  C<< <patrick.hochstenbach@ugent.be> >>
-Kjetil Kjernsmo E<lt>kjetilk@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
 This software is copyright (c) 2015 by Patrick Hochstenbach.
-This software is copyright (c) 2016 by Patrick Hochstenbach and Kjetil Kjernsmo.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
